@@ -2174,7 +2174,7 @@ evdev_read_model_flags(struct evdev_device *device)
 		MODEL(CYAPA),
 		MODEL(HP_STREAM11_TOUCHPAD),
 		MODEL(LENOVO_T450_TOUCHPAD),
-		MODEL(DELL_TOUCHPAD),
+		MODEL(TOUCHPAD_VISIBLE_MARKER),
 		MODEL(TRACKBALL),
 		MODEL(APPLE_MAGICMOUSE),
 		MODEL(HP8510_TOUCHPAD),
