@@ -406,6 +406,8 @@ extern struct litest_test_device litest_wacom_cintiq_13hdt_pen_device;
 extern struct litest_test_device litest_wacom_cintiq_13hdt_pad_device;
 extern struct litest_test_device litest_wacom_hid4800_tablet_device;
 extern struct litest_test_device litest_mouse_wheel_click_count_device;
+extern struct litest_test_device litest_acer_hawaii_keyboard_device;
+extern struct litest_test_device litest_acer_hawaii_touchpad_device;
 
 struct litest_test_device* devices[] = {
 	&litest_synaptics_clickpad_device,
@@ -463,6 +465,8 @@ struct litest_test_device* devices[] = {
 	&litest_wacom_cintiq_13hdt_pad_device,
 	&litest_wacom_hid4800_tablet_device,
 	&litest_mouse_wheel_click_count_device,
+	&litest_acer_hawaii_keyboard_device,
+	&litest_acer_hawaii_touchpad_device,
 	NULL,
 };
 
