@@ -225,6 +225,8 @@ enum litest_device_type {
 	LITEST_WACOM_CINTIQ_13HDT_FINGER,
 	LITEST_WACOM_HID4800_PEN,
 	LITEST_MOUSE_WHEEL_CLICK_COUNT,
+	LITEST_ACER_HAWAII_KEYBOARD,
+	LITEST_ACER_HAWAII_TOUCHPAD,
 };
 
 enum litest_device_feature {
