@@ -181,6 +181,9 @@ usage(void)
 	       "If stdin is a pipe, mode defaults to 'sequence' and the pipe is read \n"
 	       "for delta coordinates\n"
 	       "\n"
+	       "Delta coordinates passed into this tool must be in dpi as\n"
+	       "specified by the --dpi argument\n"
+	       "\n"
 	       "Output best viewed with gnuplot. See output for gnuplot commands\n");
 }
 
@@ -202,7 +205,8 @@ main(int argc, char **argv)
 	accel_profile_func_t profile = NULL;
 
 	enum {
-		OPT_MODE = 1,
+		OPT_HELP = 1,
+		OPT_MODE,
 		OPT_NEVENTS,
 		OPT_MAXDX,
 		OPT_STEP,
@@ -215,6 +219,7 @@ main(int argc, char **argv)
 		int c;
 		int option_index = 0;
 		static struct option long_options[] = {
+			{"help", 0, 0, OPT_HELP },
 			{"mode", 1, 0, OPT_MODE },
 			{"nevents", 1, 0, OPT_NEVENTS },
 			{"maxdx", 1, 0, OPT_MAXDX },
@@ -231,6 +236,10 @@ main(int argc, char **argv)
 			break;
 
 		switch (c) {
+		case OPT_HELP:
+			usage();
+			exit(0);
+			break;
 		case OPT_MODE:
 			if (streq(optarg, "accel"))
 				print_accel = true;
